@@ -9,7 +9,7 @@
 # using table from Muller et al., 1993, Geology.
 gmt begin ex20
 	gmt set PROJ_LENGTH_UNIT inch
-	gmt coast -Rg -JR9i -B -B+t"Hotspot Islands and Hot Cities" -Gdarkgreen -Slightblue -A5000
+	gmt coast -Rg -JR22c -B -B+t"Hotspot Islands and Hot Cities" -Gdarkgreen -Slightblue -A5000
 	gmt plot @hotspots.txt -Skvolcano -Wthinnest -Gred
 
 	# Overlay a few bullseyes at NY, Cairo, Perth, and Montevideo
