@@ -3,24 +3,24 @@
 #
 # Purpose:      Illustrate different statistical distributions in gmtmath
 # GMT modules:  math, set, plot, text
+# Unix progs:	rm
 #
 
 gmt begin ex50
 	# Left column have all the PDFs
-	gmt set FONT_ANNOT_PRIMARY 10p,Helvetica,black
 	# Binomial distribution
 	gmt math -T0/8/1 0.25 8 T BPDF = p.txt
-	gmt plot -R-0.6/8.6/0/0.35 -JX7.5c/1.25c -Glightgreen p.txt -Sb0.8u -W0.5p -BWS -Bxa1 -Byaf
+	gmt plot -R-0.6/8.6/0/0.35 -JX7.5c/1.25c -Glightgreen p.txt -Sb0.8q -W0.5p -BWS -Bxa1 -Byaf
 	# Poisson distribution
 	gmt math -T0/8/1 T 2 PPDF = p.txt
-	gmt plot -R-0.6/8.6/0/0.3 -Glightgreen p.txt -Sb0.8u -W0.5p -BWS -Bxa1 -Byaf -Y2.25c
+	gmt plot -R-0.6/8.6/0/0.3 -Glightgreen p.txt -Sb0.8q -W0.5p -BWS -Bxa1 -Byaf -Y2.25c
 	# Plot normal distribution
 	gmt math -T-4/4/0.1 T ZPDF = p.txt
 	gmt plot -R-4/4/0/0.4 p.txt -L+yb -Glightgreen -W1p -BWS -Bxa1 -Byaf -Y2.25c
 	# Plot t distribution
-	gmt plot -R-4/4/0/0.4 p.txt -W1p,lightgray -BWS -Bxa1 -Byaf -Y2.25c
+	gmt plot -R-4/4/0/0.4 p.txt -W1p,lightgray -Y2.25c
 	gmt math -T-4/4/0.1 T 3 TPDF = p.txt
-	gmt plot p.txt -L+yb -Glightgreen -W1p
+	gmt plot p.txt -L+yb -Glightgreen -W1p -BWS -Bxa1 -Byaf
 	# Plot F distribution
 	gmt math -T0/6/0.02 T 20 12 FPDF = p.txt
 	gmt plot -R0/6/0/1.02 p.txt -L+yb -Glightgreen -W1p -BWS -Bxa1 -Byaf -Y2.25c
@@ -42,17 +42,17 @@ gmt begin ex50
 	# Right column has all the CDF
 	# Plot binomial cumulative distribution
 	gmt math -T0/8/1 0.25 8 T BCDF = p.txt
-	gmt plot -R-0.6/8.6/0/1.02 -Glightred p.txt -Sb0.8u -W0.5p -BES -Bxa1 -Byaf -X9c -Y-8.1i
+	gmt plot -R-0.6/8.6/0/1.02 -Glightred p.txt -Sb0.8q -W0.5p -BES -Bxa1 -Byaf -X9c -Y-8.1i
 	# Plot Poisson cumulative distribution
 	gmt math -T0/8/1 T 2 PCDF = p.txt
-	gmt plot -R-0.6/8.6/0/1.02 -Glightred p.txt -Sb0.8u -W0.5p -BES -Bxa1 -Byaf -Y2.25c
+	gmt plot -R-0.6/8.6/0/1.02 -Glightred p.txt -Sb0.8q -W0.5p -BES -Bxa1 -Byaf -Y2.25c
 	# Plot normal cumulative distribution
 	gmt math -T-4/4/0.1 T ZCDF = p.txt
 	gmt plot -R-4/4/0/1.02 p.txt -L+yb -Glightred -W1p -BES -Bxa1 -Byaf -Y2.25c
 	# Plot t cumulative distribution
-	gmt plot -R-4/4/0/1.02 p.txt -W1p,lightgray -BES -Bxa1 -Byaf -Y2.25c
+	gmt plot -R-4/4/0/1.02 p.txt -W1p,lightgray -Y2.25c
 	gmt math -T-4/4/0.1 T 3 TCDF = p.txt
-	gmt plot p.txt -L+yb -Glightred -W1p
+	gmt plot p.txt -L+yb -Glightred -W1p -BES -Bxa1 -Byaf
 	# Plot F cumulative distribution
 	gmt math -T0/6/0.02 T 20 12 FCDF = p.txt
 	gmt plot -R0/6/0/1.02 p.txt -L+yb -Glightred -W1p -BES -Bxa1 -Byaf -Y2.25c
