@@ -1,4 +1,4 @@
-"/ISO-8859-15_Encoding [\n\
+"/ISO-8859-7_Encoding [\n\
 /.notdef	/.notdef	/.notdef	/.notdef	/.notdef	/.notdef	/.notdef	/.notdef\n\
 /.notdef	/.notdef	/.notdef	/.notdef	/.notdef	/.notdef	/.notdef	/.notdef\n\
 /.notdef	/.notdef	/.notdef	/.notdef	/.notdef	/.notdef	/.notdef	/.notdef\n\
@@ -19,16 +19,16 @@
 /.notdef	/.notdef	/.notdef	/.notdef	/.notdef	/.notdef	/.notdef	/.notdef\n\
 /.notdef	/.notdef	/.notdef	/.notdef	/.notdef	/.notdef	/.notdef	/.notdef\n\
 /.notdef	/.notdef	/.notdef	/.notdef	/.notdef	/.notdef	/.notdef	/.notdef\n\
-/uni00A0	/exclamdown	/cent		/sterling	/Euro		/yen		/Scaron		/section\n\
-/scaron		/copyright	/ordfeminine	/guillemotleft	/logicalnot	/uni00AD	/registered	/macron\n\
-/degree		/plusminus	/twosuperior	/threesuperior	/Zcaron		/mu		/paragraph	/periodcentered\n\
-/zcaron		/onesuperior	/ordmasculine	/guillemotright	/OE		/oe		/Ydieresis	/questiondown\n\
-/Agrave		/Aacute		/Acircumflex	/Atilde		/Adieresis	/Aring		/AE		/Ccedilla\n\
-/Egrave		/Eacute		/Ecircumflex	/Edieresis	/Igrave		/Iacute		/Icircumflex	/Idieresis\n\
-/Eth		/Ntilde		/Ograve		/Oacute		/Ocircumflex	/Otilde		/Odieresis	/multiply\n\
-/Oslash		/Ugrave		/Uacute		/Ucircumflex	/Udieresis	/Yacute		/Thorn		/germandbls\n\
-/agrave		/aacute		/acircumflex	/atilde		/adieresis	/aring		/ae		/ccedilla\n\
-/egrave		/eacute		/ecircumflex	/edieresis	/igrave		/iacute		/icircumflex	/idieresis\n\
-/eth		/ntilde		/ograve		/oacute		/ocircumflex	/otilde		/odieresis	/divide\n\
-/oslash		/ugrave		/uacute		/ucircumflex	/udieresis	/yacute		/thorn		/ydieresis\n\
+/uni00A0	/quoteleft	/quoteright	/sterling	/Euro		/uni20AF	/brokenbar	/section\n\
+/dieresis	/copyright	/uni037A	/guillemotleft	/logicalnot	/uni00AD	/.notdef	/afii00208\n\
+/degree		/plusminus	/twosuperior	/threesuperior	/tonos		/dieresistonos	/Alphatonos	/periodcentered\n\
+/Epsilontonos	/Etatonos	/Iotatonos	/guillemotright	/Omicrontonos	/onehalf	/Upsilontonos	/Omegatonos\n\
+/iotadieresistonos	/Alpha		/Beta		/Gamma		/uni0394	/Epsilon	/Zeta		/Eta\n\
+/Theta		/Iota		/Kappa		/Lambda		/Mu		/Nu		/Xi		/Omicron\n\
+/Pi		/Rho		/.notdef	/Sigma		/Tau		/Upsilon	/Phi		/Chi\n\
+/Psi		/uni03A9	/Iotadieresis	/Upsilondieresis	/alphatonos	/epsilontonos	/etatonos	/iotatonos\n\
+/upsilondieresistonos	/alpha		/beta		/gamma		/delta		/epsilon	/zeta		/eta\n\
+/theta		/iota		/kappa		/lambda		/uni03BC	/nu		/xi		/omicron\n\
+/pi		/rho		/uni03C2	/sigma		/tau		/upsilon	/phi		/chi\n\
+/psi		/omega		/iotadieresis	/upsilondieresis	/omicrontonos	/upsilontonos	/omegatonos	/.notdef\n\
 ] def\n",
