@@ -1,6 +1,6 @@
 /*--------------------------------------------------------------------
  *
- *	Copyright (c) 1991-2024 by the GMT Team (https://www.generic-mapping-tools.org/team.html)
+ *	Copyright (c) 1991-2025 by the GMT Team (https://www.generic-mapping-tools.org/team.html)
  *	See LICENSE.TXT file for copying and redistribution conditions.
  *
  *	This program is free software; you can redistribute it and/or modify
@@ -446,7 +446,7 @@ GMT_LOCAL uint64_t gmtvector_fix_up_path_cartesian (struct GMT_CTRL *GMT, double
 	if (step <= 0.0) step = 1.0;	/* Sanity valve; if step not given we set it to 1 */
 
 	for (i = 1; i < n; i++) {
-		if (mode == GMT_STAIRS_Y) {	/* First follow x, then y */
+		if (mode == GMT_STAIRS_X) {	/* First follow x, then y */
 			n_step = lrint (fabs (x[i] - x[i-1]) / step);
 			for (j = 1; j <= n_step; j++) {
 				c = j / (double)n_step;
@@ -465,7 +465,7 @@ GMT_LOCAL uint64_t gmtvector_fix_up_path_cartesian (struct GMT_CTRL *GMT, double
 			}
 			k = 0;
 		}
-		else if (mode == GMT_STAIRS_X) {	/* First follow y, then x */
+		else if (mode == GMT_STAIRS_Y) {	/* First follow y, then x */
 			n_step = lrint (fabs (y[i]-y[i-1]) / step);
 			for (j = 1; j <= n_step; j++) {
 				c = j / (double)n_step;
@@ -1378,7 +1378,7 @@ void gmt_matrix_matrix_mult (struct GMT_CTRL *GMT, double *A, double *B, uint64_
 #else
 	dgemm_ ("t", tr, &na, &nb, &nc, &one, A, &nd, B, &ne, &zero, C, &nf);
 #endif
-	
+
 #else
 	/* Plain matrix multiplication, no speed up; space must exist */
 	uint64_t row, col, k, a_ij, b_ij, c_ij, n_colsA = n_rowsB;
@@ -1604,7 +1604,7 @@ uint64_t gmt_fix_up_path (struct GMT_CTRL *GMT, double **a_lon, double **a_lat,
 		else	/* No boost needed */
 			boost = 1.0;
 
-		if (mode == GMT_STAIRS_Y) {	/* First follow meridian, then parallel */
+		if (mode == GMT_STAIRS_X) {	/* First follow parallel, then meridian */
 			gmt_M_set_delta_lon (lon[i-1], lon[i], dlon);	/* Beware of jumps due to sign differences */
 			lon_i = lon[i-1] + dlon;	/* Use lon_i instead of lon[i] in the marching since this avoids any jumping */
 			theta = fabs (dlon) * cosd (lat[i-1]);
@@ -1628,7 +1628,7 @@ uint64_t gmt_fix_up_path (struct GMT_CTRL *GMT, double **a_lon, double **a_lat,
 			k = 0;
 		}
 
-		else if (mode == GMT_STAIRS_X) {	/* First follow parallel, then meridian */
+		else if (mode == GMT_STAIRS_Y) {	/* First follow meridian, then parallel */
 			theta = fabs (lat[i]-lat[i-1]);
 			n_step = lrint (theta / step);
 			for (j = 1; j <= n_step; j++) {
