@@ -1,6 +1,6 @@
 /*--------------------------------------------------------------------
  *
- *	Copyright (c) 1991-2024 by the GMT Team (https://www.generic-mapping-tools.org/team.html)
+ *	Copyright (c) 1991-2025 by the GMT Team (https://www.generic-mapping-tools.org/team.html)
  *	See LICENSE.TXT file for copying and redistribution conditions.
  *
  *	This program is free software; you can redistribute it and/or modify
@@ -59,7 +59,7 @@
 #define THIS_MODULE_PURPOSE	"Plot continents, countries, shorelines, rivers, and borders"
 #define THIS_MODULE_KEYS	">?},>DE-lL"
 #define THIS_MODULE_NEEDS	"JR"
-#define THIS_MODULE_OPTIONS "->BJKOPRUVXYbdptxy" GMT_OPT("Zc")
+#define THIS_MODULE_OPTIONS "->BJKOPRUVXYbdgptxy" GMT_OPT("Zc")
 
 #define LAKE	0
 #define RIVER	1
@@ -199,10 +199,10 @@ static int usage (struct GMTAPI_CTRL *API, int level) {
 	if (level == GMT_MODULE_PURPOSE) return (GMT_NOERROR);
 	GMT_Usage (API, 0, "usage: %s %s %s [%s] [%s] [-C<fill>[+l|r]] [-D<resolution>[+f]] [-E%s] "
 		"[-G[<fill>]] [-F%s] [-I<feature>[/<pen>]] %s [-L%s] [-M] [-N<feature>[/<pen>]] %s%s[-Q] [-S[<fill>]] "
-		"[-Td%s] [-Tm%s] [%s] [%s] [-W[<feature>/][<pen>]] [%s] [%s] [%s] %s[%s] [%s] [%s] [%s]%s [%s]\n",
+		"[-Td%s] [-Tm%s] [%s] [%s] [-W[<feature>/][<pen>]] [%s] [%s] [%s] [%s] %s[%s] [%s] [%s] [%s]%s [%s]\n",
 		name, GMT_J_OPT, GMT_Rgeoz_OPT, GMT_A_OPT, GMT_B_OPT, DCW_OPT, GMT_PANEL, API->K_OPT, GMT_SCALE, API->O_OPT,
 		API->P_OPT, GMT_TROSE_DIR, GMT_TROSE_MAG, GMT_U_OPT, GMT_V_OPT, GMT_X_OPT, GMT_Y_OPT, GMT_bo_OPT, API->c_OPT,
-		GMT_do_OPT, GMT_p_OPT, GMT_t_OPT, GMT_colon_OPT, dbg, GMT_PAR_OPT);
+		GMT_do_OPT, GMT_g_OPT, GMT_p_OPT, GMT_t_OPT, GMT_colon_OPT, dbg, GMT_PAR_OPT);
 
 	if (level == GMT_SYNOPSIS) return (GMT_MODULE_SYNOPSIS);
 
@@ -216,7 +216,7 @@ static int usage (struct GMTAPI_CTRL *API, int level) {
 	GMT_Usage (API, 3, "+l Set lake fill.");
 	GMT_Usage (API, 3, "+r Set river-lake fill.");
 	gmt_GSHHG_resolution_syntax (API->GMT, 'D', "Alternatively, choose (a)uto to automatically select the best "
-		"resolution given the chosen region.");
+		"resolution given the chosen region [Default in modern mode].");
 	gmt_DCW_option (API, 'E', 1U);
 	gmt_mappanel_syntax (API->GMT, 'F', "Specify a rectangular panel behind the map scale or rose.", 3);
 	GMT_Usage (API, -2, "Note: If using both -L and -T, use -Fl and -Ft.");
@@ -268,6 +268,9 @@ static int usage (struct GMTAPI_CTRL *API, int level) {
 	GMT_Usage (API, 3, "4: Lake in island in lake shores.");
 	GMT_Usage (API, -2, "Note: When feature-specific pens are used, those not set are deactivated.");
 	GMT_Option (API, "X,bo,c,do,p,t");
+	GMT_Usage (API, 1, "\n-gD<dist> Short version of the global -g option. Here it is used to set the distance, in map "
+		"units, above which we consider to have a gap. Useful for the Spilhaus projection (though we automatically set it) "
+		"and when line wrapping on dateline was not correctly detected.");
 #ifdef DEBUG
 	GMT_Usage (API, 1, "\n-+<bin> (repeatable up to 16 times)");
 	GMT_Usage (API, -2, "Plot only the specified bins (debug option).");
@@ -533,6 +536,14 @@ static int parse (struct GMT_CTRL *GMT, struct PSCOAST_CTRL *Ctrl, struct GMT_OP
 		}
 	}
 
+	/* If Spilhaus projection and no -g used, set a default value. */
+	if (!GMT->common.g.active && GMT->current.proj.projection == GMT_PROJ4_SPILHAUS) {
+		gmt_parse_g_option(GMT, "D1");
+		GMT->common.g.active = true;
+		if (!((GMT->common.R.wesn[XHI] - GMT->common.R.wesn[XLO]) == 360 && GMT->common.R.wesn[YLO] == -90 && GMT->common.R.wesn[YHI] == 90))
+			GMT_Report(API, GMT_MSG_WARNING, "Using a non-global region with Spilhaus projection has unknown effects.\n");
+	}
+
 	if ((error = gmt_DCW_list (GMT, &(Ctrl->E.info)))) {	/* This is either success or failure... */
 		if (error != GMT_DCW_LIST)
 			return (1);	/* Not good */
@@ -731,10 +742,46 @@ GMT_LOCAL int pscoast_check_antipode_status (struct GMT_CTRL *GMT, struct GMT_SH
 	return (GMT_NOERROR);
 }
 
-#define bailout(code) {gmt_M_free_options (mode); return (code);}
-#define Return(code) {Free_Ctrl (GMT, Ctrl); gmt_end_module (GMT, GMT_cpy); bailout (code);}
+/*
+ * Checks if the given GMT_CTRL structure's J.proj4string contains false eastings/northings.
+ * If found, strip them and re-initializes the coordinate transformations.
+ * See issue: https://github.com/GenericMappingTools/gmt/issues/8536 
+ *
+ * Return true if false eastings/northings are found and coordinate transformations are re-initialized,
+ * false otherwise
+ */
+GMT_LOCAL bool pscoast_proj4_no_x0y0(struct GMT_CTRL *GMT) {
+	unsigned int pos = 0;
+	size_t k;
+	char *pch1 = NULL, *pch2 = NULL, token[GMT_LEN64] = {""};
+	char *pStr = strdup(GMT->common.J.proj4string);
+	if ((pch1 = strstr(pStr, "+x_0=")) != NULL) {
+		gmt_strtok (pch1, " \t+", &pos, token);
+		if ((pch2 = strstr(pStr, token)) != NULL) {
+			for (k = 0; k < strlen(token); k++) pch2[k] = ' ';
+		}
+	}
+	if ((pch1 = strstr(pStr, "+y_0=")) != NULL) {
+		pos = 0;	gmt_strtok (pch1, " \t+", &pos, token);
+		if ((pch2 = strstr(pStr, token)) != NULL) {
+			for (k = 0; k < strlen(token); k++) pch2[k] = ' ';
+		}
+	}
+	/* If we have found false eastings/northings, we need to re-initialize the coordinate transformations */
+	if (pos > 0) {
+		if (GMT->current.gdal_read_in.hCT_fwd) OCTDestroyCoordinateTransformation(GMT->current.gdal_read_in.hCT_fwd);
+		if (GMT->current.gdal_read_in.hCT_inv) OCTDestroyCoordinateTransformation(GMT->current.gdal_read_in.hCT_inv);
+		GMT->current.gdal_read_in.hCT_fwd = gmt_OGRCoordinateTransformation(GMT, "+proj=latlong +datum=WGS84", pStr);
+		GMT->current.gdal_read_in.hCT_inv = gmt_OGRCoordinateTransformation(GMT, pStr, "+proj=latlong +datum=WGS84");
+		return true;
+	}
+	return false;
+}
 
-EXTERN_MSC int GMT_pscoast (void *V_API, int mode, void *args) {
+#define bailout(code) {gmt_M_free_options(mode); return (code);}
+#define Return(code) {Free_Ctrl(GMT, Ctrl); gmt_end_module(GMT, GMT_cpy); bailout(code);}
+
+EXTERN_MSC int GMT_pscoast(void *V_API, int mode, void *args) {
 	/* High-level function that implements the pscoast task */
 
 	int i, np, ind, bin = 0, base, anti_bin = -1, np_new, k, last_k, err, bin_trouble, error, n;
@@ -743,7 +790,7 @@ EXTERN_MSC int GMT_pscoast (void *V_API, int mode, void *args) {
 	bool shift = false, need_coast_base, recursive, greenwich = false, possibly_donut_hell = false;
 	bool clobber_background = false, paint_polygons = false, donut, double_recursive = false;
 	bool donut_hell = false, world_map_save, clipping;
-	bool clip_to_extend_lines = false;
+	bool clip_to_extend_lines = false, reset_CT_transformers = false;
 
 	double bin_x[5], bin_y[5], out[2], *xtmp = NULL, *ytmp = NULL;
 	double west_border = 0.0, east_border = 0.0, anti_lon = 0.0, anti_lat = -90.0, edge = 720.0;
@@ -785,6 +832,10 @@ EXTERN_MSC int GMT_pscoast (void *V_API, int mode, void *args) {
 
 	/* Check and interpret the command line arguments */
 
+	if (!Ctrl->M.active && !Ctrl->Q.active && GMT->current.proj.is_proj4 && GMT->common.J.proj4string[0])
+		reset_CT_transformers = pscoast_proj4_no_x0y0(GMT);	/* x_0, y_0 in proj4 string, screw the map coords */
+
+
 	gmt_init_fill (GMT, &no_fill, -1.0, -1.0, -1.0);
 	if (GMT->current.setting.run_mode == GMT_MODERN && !Ctrl->D.active)
 		Ctrl->D.set = 'a';	/* Auto-select resolution under modern mode if -D not given */
@@ -1324,6 +1375,16 @@ EXTERN_MSC int GMT_pscoast (void *V_API, int mode, void *args) {
 		gmt_br_cleanup (GMT, &b);
 	}
 
+	/* If we had temporaryly changed the proj4 coordinate transformes, must undo that change */
+	if (reset_CT_transformers) {
+		OCTDestroyCoordinateTransformation(GMT->current.gdal_read_in.hCT_fwd);
+		OCTDestroyCoordinateTransformation(GMT->current.gdal_read_in.hCT_inv);
+		GMT->current.gdal_read_in.hCT_fwd =
+			gmt_OGRCoordinateTransformation(GMT, "+proj=latlong +datum=WGS84", GMT->common.J.proj4string);
+		GMT->current.gdal_read_in.hCT_inv =
+			gmt_OGRCoordinateTransformation(GMT, GMT->common.J.proj4string, "+proj=latlong +datum=WGS84");
+	}
+
 	if (!Ctrl->M.active) {	/* Wrap of the plotting codes */
 		if (clip_to_extend_lines) gmt_map_clip_off (GMT);
 		if (GMT->current.map.frame.init) {
