@@ -32,7 +32,7 @@ double rint(double x)
 {
 	int32_t i0,j0,sx;
 	uint32_t i,i1;
-	double w,t;
+	double w=0.0,t;
 	EXTRACT_WORDS(i0,i1,x);
 	sx = (i0>>31)&1;
 	j0 = ((i0>>20)&0x7ff)-0x3ff;
